ArmorVault class

ArmorVault v2.0.3 - Production Ready Secret Storage

Constructors

ArmorVault()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

api_key String
API_KEY
no setter
aws_access_key String
AWS_ACCESS_KEY
no setter
database_url String
DATABASE_URL
no setter
secret_token String
SECRET_TOKEN
no setter
stripe_key String
STRIPE_KEY
no setter